Operation enum

The data structure representing a diff is a List of Diff objects: {Diff(Operation.delete, 'Hello'), Diff(Operation.insert, 'Goodbye'), Diff(Operation.equal, ' world.')} which means: delete 'Hello', add 'Goodbye' and keep ' world.'

Inheritance
Available extensions

Values

delete → const Operation
const Operation(0)
insert → const Operation
const Operation(1)
equal → const Operation
const Operation(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseJson(int value) → Operation

Constants

values → const List<Operation>
A constant List of the values in this enum, in order of their declaration.