Patch class

Class representing one patch operation.

Constructors

Patch([List<Diff>? diffs, int start1 = 0, int start2 = 0, int length1 = 0, int length2 = 0])
Constructor. Initializes with an empty list of diffs.
Patch.fromJson(List json)

Properties

diffs ↔ List<Diff>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length1 ↔ int
getter/setter pair
length2 ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start1 ↔ int
getter/setter pair
start2 ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGnuString() → String
Emulate GNU diff's format. Header: @@ -382,8 +481,9 @@ Indices are printed as 1-based, not 0-based. Returns the GNU diff string.
toJson() → List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited